@@ -1,5 +1,5 @@
 package Object::RateLimiter;
-$Object::RateLimiter::VERSION = '1.002001';
+$Object::RateLimiter::VERSION = '1.003001';
 use strictures 2;
 
 use Carp 'confess';
@@ -10,7 +10,6 @@ use Time::HiRes  'time';
 use namespace::clean;
 
 use overload
-  bool     => sub { 1 },
   '&{}'    => sub {
     my $self = shift;
     sub { $self->delay }
@@ -18,7 +17,7 @@ use overload
   fallback => 1;
 
 use Object::ArrayType::New
-  [ events  => '', seconds => 'SECS', '' => 'QUEUE' ];
+  [ events  => '', seconds => 'SECS', _queue => 'QUEUE' ];
 sub seconds  { $_[0]->[SECS]   }
 sub events   { $_[0]->[EVENTS] }
 sub _queue   { $_[0]->[QUEUE]  }
@@ -29,6 +28,8 @@ around new => sub {
   my $self = $class->$orig(@_);
   confess "Constructor requires 'seconds =>' and 'events =>' parameters"
     unless defined $self->seconds and defined $self->events;
+  $self->[QUEUE] = array(@{ $self->_queue })
+    if $self->_queue and ref $self->_queue eq 'ARRAY';
   $self
 };
 
@@ -36,14 +37,18 @@ sub clone {
   my ($self, %params) = @_;
   $params{events}  = $self->events  unless defined $params{events};
   $params{seconds} = $self->seconds unless defined $params{seconds};
-
-  my $cloned = $self->new(%params);
-  if (my $currentq = $self->_queue) {
-    $cloned->[QUEUE] = array( $currentq->all )
-  }
-  $cloned
+  $params{_queue}  = $self->_queue  if $self->_queue;
+  $self->new(%params);
 }
 
+sub export {
+  my ($self) = @_;
+  +{
+    events   => $self->events, 
+    seconds  => $self->seconds, 
+    _queue   => $self->_queue->unbless,
+  }
+}
 
 sub delay {
   my ($self) = @_;
@@ -184,6 +189,17 @@ previous settings.
 The new limiter contains a clone of the event history; the old rate-limiter is
 left untouched.
 
+=head2 export
+
+  my $opts = $ctrl->export;
+  # ... later, perhaps after storing/retrieving ...
+  my $recreated = Object::RateLimiter->new(%$opts);
+
+Exports the current state of the rate-limiter as a reference to a hash; the
+exported hash can be fed to L</new> to recreate the rate-limiter.
+
+This is useful if the rate-limiter's state must be stored persistently. 
+
 =head2 delay
 
   if (my $delay = $ctrl->delay) {
